about summary refs log tree commit diff
path: root/pkgs/misc/scrcpy
diff options
context:
space:
mode:
authorHarsh Shandilya <me@msfjarvis.dev>2023-06-22 12:34:12 +0530
committerHarsh Shandilya <me@msfjarvis.dev>2023-06-25 23:40:42 +0530
commit65dc76518a840ac1dbe49d4f63b2d603b34fea02 (patch)
tree8c284e91782482643e4c4669a03e548450696056 /pkgs/misc/scrcpy
parentb82265108172c9de5a897202c6b18eca626f2d3b (diff)
scrcpy: 2.0 -> 2.1
Diffstat (limited to 'pkgs/misc/scrcpy')
-rw-r--r--pkgs/misc/scrcpy/default.nix21
1 files changed, 5 insertions, 16 deletions
diff --git a/pkgs/misc/scrcpy/default.nix b/pkgs/misc/scrcpy/default.nix
index eadd3d892393a..d6fb53dd86d93 100644
--- a/pkgs/misc/scrcpy/default.nix
+++ b/pkgs/misc/scrcpy/default.nix
@@ -1,6 +1,5 @@
 { lib
 , stdenv
-, fetchpatch
 , fetchurl
 , fetchFromGitHub
 , makeWrapper
@@ -17,10 +16,10 @@
 }:
 
 let
-  version = "2.0";
+  version = "2.1";
   prebuilt_server = fetchurl {
     url = "https://github.com/Genymobile/scrcpy/releases/download/v${version}/scrcpy-server-v${version}";
-    sha256 = "sha256-niQWFfV4zWkLtDMRAA3r3s9qnFCnCCsAGVLxj28h3cI=";
+    sha256 = "sha256-W4vxlAJkuTDHGhxhTFfaIkf1Ky1CQLyoZcxtNm3/Zog=";
   };
 in
 stdenv.mkDerivation rec {
@@ -31,24 +30,14 @@ stdenv.mkDerivation rec {
     owner = "Genymobile";
     repo = pname;
     rev = "v${version}";
-    sha256 = "sha256-PWH+XLKraFfjXovnZpREXBaQVyOyP8yIMYDMiF6ddXg=";
+    sha256 = "sha256-M5zOKwqQ0y70gsI+c0Or7hUzz4fH/8DqcOeKq4Vryc4=";
   };
 
-  # Remove in the next patch release
-  patches = [
-    (fetchpatch {
-      name = "fix-macos-build-error.patch";
-      url = "https://github.com/Genymobile/scrcpy/commit/6b769675fa68e60c9765022e43c4d7b1e329353a.patch";
-      hash = "sha256-lQx01HI0nTWdZFusLIswZT2iOgkP84btqF6F58tGNko=";
-    })
-  ];
-
-  # postPatch:
-  #   screen.c: When run without a hardware accelerator, this allows the command to continue working rather than failing unexpectedly.
+  #   display.c: When run without a hardware accelerator, this allows the command to continue working rather than failing unexpectedly.
   #   This can happen when running on non-NixOS because then scrcpy seems to have a hard time using the host OpenGL-supporting hardware.
   #   It would be better to fix the OpenGL problem, but that seems much more intrusive.
   postPatch = ''
-    substituteInPlace app/src/screen.c \
+    substituteInPlace app/src/display.c \
       --replace "SDL_RENDERER_ACCELERATED" "SDL_RENDERER_ACCELERATED || SDL_RENDERER_SOFTWARE"
   '';